@@ -597,6 +597,9 @@ class WebEngineTab(browsertab.AbstractTab):
 
     @pyqtSlot()
     def _restore_zoom(self):
+        if sip.isdeleted(self._widget):
+            # https://github.com/qutebrowser/qutebrowser/issues/3498
+            return
         if self._saved_zoom is None:
             return
         self.zoom.set_factor(self._saved_zoom)
